@@ -37,18 +37,25 @@ def nice_string(xs):
             for k1, v1 in xs.items()
         ) + '}'
     if isinstance(xs, set):
+        if not xs:
+            return repr(xs)
         return '{%s}' % (
             ', '.join(
                 map(nice_string, xs)
             )
         )
     if isinstance(xs, frozenset):
+        if not xs:
+            return repr(xs)
         return "frozenset(%s)" % (nice_string(set(xs)),)
     try:
         return xs.__name__
     except AttributeError:
         pass
 
+    if isinstance(xs, descriptors.Just):
+        return repr(xs)
+
     try:
         d = xs.__dict__
     except AttributeError:
@@ -215,21 +222,22 @@ class FixedBoundedFloatStrategy(SearchStrategy):
     descriptor = float
 
     parameter = params.CompositeParameter(
-        p=params.UniformFloatParameter(0, 1),
-        n=params.ExponentialParameter(0.5),
+        cut=params.UniformFloatParameter(0, 1),
+        leftwards=params.BiasedCoin(0.5),
     )
 
     def __init__(self, lower_bound, upper_bound):
-        self.lower_bound = lower_bound
-        self.upper_bound = upper_bound
+        self.lower_bound = float(lower_bound)
+        self.upper_bound = float(upper_bound)
 
     def produce(self, random, pv):
-        alpha = pv.p * pv.n
-        beta = (1 - pv.p) * pv.n
-        result = self.lower_bound + (
-            self.upper_bound - self.lower_bound
-        ) * random.betavariate(alpha, beta)
-        return result
+        if pv.leftwards:
+            left = self.lower_bound
+            right = pv.cut
+        else:
+            left = pv.cut
+            right = self.upper_bound
+        return left + random.random() * (right - left)
 
     def simplify(self, value):
         yield self.lower_bound
@@ -648,6 +656,9 @@ class JustStrategy(SearchStrategy):
     def __init__(self, value):
         self.descriptor = descriptors.Just(value)
 
+    def __repr__(self):
+        return "JustStrategy(value=%r)" % (self.descriptor.value,)
+
     parameter = params.CompositeParameter()
 
     def produce(self, random, pv):
@@ -663,7 +674,7 @@ class RandomWithSeed(r.Random):
         self.seed = seed
 
     def __repr__(self):
-        return "Random(%s)" % (self.seed,)
+        return "RandomWithSeed(%s)" % (self.seed,)
 
     def __copy__(self):
         r = RandomWithSeed(self.seed)
@@ -691,3 +702,16 @@ class RandomStrategy(SearchStrategy):
 
     def could_have_produced(self, value):
         return isinstance(value, RandomWithSeed)
+
+
+class SampledFromStrategy(SearchStrategy):
+    def __init__(self, elements):
+        self.elements = tuple(elements)
+        self.descriptor = descriptors.SampledFrom(self.elements)
+        self.parameter = params.NonEmptySubset(self.elements)
+
+    def produce(self, random, pv):
+        return random.choice(pv)
+
+    def could_have_produced(self, value):
+        return value in self.elements
